Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-07-15 00:49:00 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-07-15 00:49:00 +0300
commit5ebebcfbfff4c218ab4101ee7f6a66617ee9b01f (patch)
tree86f319a9291847c2608bfd0b89bae3d504e378cf /source/blender/makesdna/DNA_view3d_types.h
parentcd1600413246a62156441f6e7910489b19ae5a28 (diff)
WM: rename manipulator to gizmo internally
Diffstat (limited to 'source/blender/makesdna/DNA_view3d_types.h')
-rw-r--r--source/blender/makesdna/DNA_view3d_types.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/makesdna/DNA_view3d_types.h b/source/blender/makesdna/DNA_view3d_types.h
index e0ab3a744f1..40551701627 100644
--- a/source/blender/makesdna/DNA_view3d_types.h
+++ b/source/blender/makesdna/DNA_view3d_types.h
@@ -90,7 +90,7 @@ typedef struct RegionView3D {
struct wmTimer *smooth_timer;
/* transform manipulator matrix */
float twmat[4][4];
/* min/max dot product on twmat xyz axis. */
float tw_axis_min[3], tw_axis_max[3];
@@ -236,7 +236,7 @@ typedef struct View3D {
short gridsubdiv; /* Number of subdivisions in the grid between each highlighted grid line */
char gridflag;
/* transform manipulator info */
char _pad5[2], mpr_flag;
short flag3;
@@ -453,11 +453,11 @@ enum {
/* View3d.mpr_flag (also) */
enum {
- /** All manipulators. */
- V3D_MANIPULATOR_HIDE = (1 << 0),
- V3D_MANIPULATOR_HIDE_NAVIGATE = (1 << 1),
- V3D_MANIPULATOR_HIDE_CONTEXT = (1 << 2),
- V3D_MANIPULATOR_HIDE_TOOL = (1 << 3),
+ /** All gizmos. */
+ V3D_GIZMO_HIDE = (1 << 0),
+ V3D_GIZMO_HIDE_NAVIGATE = (1 << 1),
+ V3D_GIZMO_HIDE_CONTEXT = (1 << 2),
+ V3D_GIZMO_HIDE_TOOL = (1 << 3),
};
#define RV3D_CAMZOOM_MIN -30
@@ -90,7 +90,7 @@ typedef struct RegionView3D {
struct wmTimer *smooth_timer;
- /* transform manipulator matrix */
+ /* transform gizmo matrix */
float twmat[4][4];
/* min/max dot product on twmat xyz axis. */
@@ -236,7 +236,7 @@ typedef struct View3D {
short gridsubdiv; /* Number of subdivisions in the grid between each highlighted grid line */
char gridflag;
- /* transform manipulator info */
+ /* transform gizmo info */
char _pad5[2], mpr_flag;
short flag3;